package Bundle::WWW::Search::ALL;

$VERSION = '1.03';

1;

__END__

=head1 NAME

Bundle::WWW::Search::ALL - A bundle to install all WWW::Search modules and backends

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::WWW::Search::ALL'>

=head1 CONTENTS

Bundle::WWW::Search

WWW::Search::AllTheWeb

WWW::Search::Deja

WWW::Search::Excite

WWW::Search::HotBot

M/MT/MTHURN/WWW-Search-Magellan-2.05.tar.gz

J/JS/JSMYSER/WWW-Search-OpenDirectory.tar.gz

WWW::Search::PRWire

M/MT/MTHURN/WWW-Search-Yahoo-2.07.tar.gz

=head1 DESCRIPTION

This bundle gathers together all of the modules for WWW::Search,
including all the prerequisites and all the backends.

=head1 AUTHOR

Martin Thurn E<lt>F<martinthurn@iname.com>E<gt>
(Author only of this bundle, not necessarily of the modules it lists)

=cut

